Page 56 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 56

Home

    In order to carry out the government's plan of
    population control, people were slaughtered by the
    hundreds and thousands. When the guillotine proved too
    slow, those rounded up were herded together and blown
    to pieces by rifle and cannon fire. So great was the
    slaughter that the Rhone River ran red with the blood of

    the corpses thrown into it.

    Jean Baptiste Carrier had a peculiar hatred against
    children. "They must be destroyed," he roared, and gave
    orders that they should be butchered. Under his
    command at Nantes, 500 children were driven into a

    field, and then shot, clubbed, and sabered as they clung
    to the knees of their assassins, weeping and crying for

    mercy.
    It was Carrier who devised the scheme of wholesale

    drowning in the Loire. The first experiment was made on
    about ninety old priests who were placed on a barge that
    was towed to midstream and sunk. Through cold

    December nights crowds of poor women, some carrying
    babies, some leading children by the hand, were driven
    to the river and loaded on barges to be drowned. Carrier
    referred to this as, "bathing parties." Prudhomme placed
    the death toll at no less than one million during this

    It is important to remember that the system behind the
    Reign of Terror was the plan of Robespierre to transform
    France into a Socialist State. There were to be no rich,

    no poor, only equality. Plans were put forth for every
    department of life to be placed under State control. Free

    51

    The French Revolution

    period of indiscriminate massacres.